/*  Note: You are free to use whatever license you want.
    Eventually you will be able to edit it within Glade. */

/*  uttakssystem
 *  Copyright (C) <YEAR> <AUTHORS>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <sys/stat.h>
#include <unistd.h>
#include <string.h>

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>
#include <gdk/gdkkeysyms.h>
#include "gladesig.h"
#include "gladesrc.h"

GtkWidget*
get_widget                             (GtkWidget       *widget,
                                        gchar           *widget_name)
{
  GtkWidget *parent, *found_widget;

  for (;;)
    {
      if (GTK_IS_MENU (widget))
        parent = gtk_menu_get_attach_widget (GTK_MENU (widget));
      else
        parent = widget->parent;
      if (parent == NULL)
        break;
      widget = parent;
    }

  found_widget = (GtkWidget*) gtk_object_get_data (GTK_OBJECT (widget),
                                                   widget_name);
  if (!found_widget)
    g_warning ("Widget not found: %s", widget_name);
  return found_widget;
}

/* This is an internally used function to set notebook tab widgets. */
void
set_notebook_tab                       (GtkWidget       *notebook,
                                        gint             page_num,
                                        GtkWidget       *widget)
{
  GtkNotebookPage *page;
  GtkWidget *notebook_page;

  page = (GtkNotebookPage*) g_list_nth (GTK_NOTEBOOK (notebook)->children, page_num)->data;
  notebook_page = page->child;
  gtk_widget_ref (notebook_page);
  gtk_notebook_remove_page (GTK_NOTEBOOK (notebook), page_num);
  gtk_notebook_insert_page (GTK_NOTEBOOK (notebook), notebook_page,
                            widget, page_num);
  gtk_widget_unref (notebook_page);
}

static GList *pixmaps_directories = NULL;

/* Use this function to set the directory containing installed pixmaps. */
void
add_pixmap_directory                   (gchar           *directory)
{
  pixmaps_directories = g_list_prepend (pixmaps_directories, g_strdup (directory));
}

/* This is an internally used function to check if a pixmap file exists. */
#ifndef G_DIR_SEPARATOR_S
#define G_DIR_SEPARATOR_S "/"
#endif
gchar*
check_file_exists                      (gchar           *directory,
                                        gchar           *filename)
{
  gchar *full_filename;
  struct stat s;
  gint status;

  full_filename = g_malloc (strlen (directory) + 1 + strlen (filename) + 1);
  strcpy (full_filename, directory);
  strcat (full_filename, G_DIR_SEPARATOR_S);
  strcat (full_filename, filename);

  status = stat (full_filename, &s);
  if (status == 0 && S_ISREG (s.st_mode))
    return full_filename;
  g_free (full_filename);
  return NULL;
}

/* This is an internally used function to create pixmaps. */
GtkWidget*
create_pixmap                          (GtkWidget       *widget,
                                        gchar           *filename)
{
  gchar *found_filename = NULL;
  GdkColormap *colormap;
  GdkPixmap *gdkpixmap;
  GdkBitmap *mask;
  GtkWidget *pixmap;
  GList *elem;

  /* We first try any pixmaps directories set by the application. */
  elem = pixmaps_directories;
  while (elem)
    {
      found_filename = check_file_exists ((gchar*)elem->data, filename);
      if (found_filename)
        break;
      elem = elem->next;
    }

  /* If we haven't found the pixmap, try the source directory. */
  if (!found_filename)
    {
      found_filename = check_file_exists ("../pixmaps", filename);
    }

  if (!found_filename)
    {
      g_print ("Couldn't find pixmap file: %s", filename);
      return NULL;
    }

  colormap = gtk_widget_get_colormap (widget);
  gdkpixmap = gdk_pixmap_colormap_create_from_xpm (NULL, colormap, &mask,
                                                   NULL, found_filename);
  g_free (found_filename);
  if (gdkpixmap == NULL)
    return NULL;
  pixmap = gtk_pixmap_new (gdkpixmap, mask);
  gdk_pixmap_unref (gdkpixmap);
  gdk_bitmap_unref (mask);
  return pixmap;
}

  GtkWidget *uttakssystem;
  GtkWidget *notebook1;
  GtkWidget *vbox1;
  GtkWidget *hbox1;
  GtkWidget *vbox2;
  GSList *system_group = NULL;
  GtkWidget *sumpoengsystem;
  GtkWidget *halver;
  GtkWidget *reduser;
  GtkWidget *table2;
  GtkWidget *label33;
  GtkWidget *label34;
  GtkWidget *label35;
  GtkWidget *label36;
  GtkWidget *label37;
  GtkWidget *label37a;
  GtkWidget *label37b;
  GtkWidget *label37c;
  GtkWidget *label37d;
  GtkWidget *label37e;
  GtkWidget *poeng1;
  GtkWidget *poeng2;
  GtkWidget *poeng3;
  GtkWidget *poeng4;
  GtkWidget *poeng5;
  GtkWidget *poeng6;
  GtkWidget *poeng7;
  GtkWidget *poeng8;
  GtkWidget *poeng9;
  GtkWidget *poeng10;
  GtkWidget *hbox3;
  GtkWidget *poengfratrekssystem;
  GtkWidget *label25;
  GtkWidget *grunntall;
  GtkWidget *label26;
  GtkWidget *akkumulering;
  GtkWidget *hbox2;
  GtkWidget *deltaksfratrekssystem;
  GtkWidget *regler;
  GtkWidget *table1;
  GtkWidget *label7;
  GtkWidget *label17;
  GtkWidget *hscale0;
  GtkWidget *hscale1;
  GtkWidget *hscale2;
  GtkWidget *hscale3;
  GtkWidget *hscale4;
  GtkWidget *hscale5;
  GtkWidget *hscale6;
  GtkWidget *hscale7;
  GtkWidget *hscale8;
  GtkWidget *hscale9;
  GtkWidget *hscale10;
  GtkWidget *hscale11;
  GtkWidget *hscale12;
  GtkWidget *hscale13;
  GtkWidget *hscale14;
  GtkWidget *hscale15;
  GtkWidget *hscale16;
  GtkWidget *hscale17;
  GtkWidget *hscale18;
  GtkWidget *hscale19;
  GtkWidget *hscale20;
  GtkWidget *hscale21;
  GtkWidget *hscale22;
  GtkWidget *hscale23;
  GtkWidget *hscale24;
  GtkWidget *hscale25;
  GtkWidget *hscale26;
  GtkWidget *hscale27;
  GtkWidget *hscale28;
  GtkWidget *hscale29;
  GtkWidget *hscale30;
  GtkWidget *hscale31;
  GtkWidget *hscale32;
  GtkWidget *hscale33;
  GtkWidget *hscale34;
  GtkWidget *hscale35;
  GtkWidget *hscale36;
  GtkWidget *hscale37;
  GtkWidget *hscale38;
  GtkWidget *hscale39;
  GtkWidget *hscale40;
  GtkWidget *hscale41;
  GtkWidget *hscale42;
  GtkWidget *hscale43;
  GtkWidget *hscale44;
  GtkWidget *hscale45;
  GtkWidget *hscale46;
  GtkWidget *hscale47;
  GtkWidget *hscale48;
  GtkWidget *hscale49;
  GtkWidget *hscale50;
  GtkWidget *hscale51;
  GtkWidget *hscale52;
  GtkWidget *hscale53;
  GtkWidget *hscale54;
  GtkWidget *hscale55;
  GtkWidget *hscale56;
  GtkWidget *hscale57;
  GtkWidget *hscale58;
  GtkWidget *hscale59;
  GtkWidget *hscale60;
  GtkWidget *hscale61;
  GtkWidget *hscale62;
  GtkWidget *hscale63;
  GtkWidget *hscale64;
  GtkWidget *hscale65;
  GtkWidget *hscale66;
  GtkWidget *hscale67;
  GtkWidget *hscale68;
  GtkWidget *hscale69;
  GtkWidget *hscale70;
  GtkWidget *hscale71;
  GtkWidget *hscale72;
  GtkWidget *hscale73;
  GtkWidget *hscale74;
  GtkWidget *hscale75;
  GtkWidget *hscale76;
  GtkWidget *hscale77;
  GtkWidget *hscale78;
  GtkWidget *hscale79;
  GtkWidget *hscale80;
  GtkWidget *hscale81;
  GtkWidget *hscale82;
  GtkWidget *hscale83;
  GtkWidget *hscale84;
  GtkWidget *hscale85;
  GtkWidget *hscale86;
  GtkWidget *hscale87;
  GtkWidget *hscale88;
  GtkWidget *hscale89;
  GtkWidget *hscale90;
  GtkWidget *hscale91;
  GtkWidget *hscale92;
  GtkWidget *hscale93;
  GtkWidget *hscale94;
  GtkWidget *hscale95;
  GtkWidget *hscale96;
  GtkWidget *hscale97;
  GtkWidget *hscale98;
  GtkWidget *hscale99;
  GtkWidget *label38;
  GtkWidget *label39;
  GtkWidget *label40;
  GtkWidget *label41;
  GtkWidget *label42;
  GtkWidget *label43;
  GtkWidget *label44;
  GtkWidget *label45;
  GtkWidget *label55;
  GtkWidget *label46;
  GtkWidget *label47;
  GtkWidget *label48;
  GtkWidget *label49;
  GtkWidget *label50;
  GtkWidget *label51;
  GtkWidget *label52;
  GtkWidget *label53;
  GtkWidget *label54;
  GtkWidget *resultat;
  GtkWidget *label30;
  GtkWidget *label31;
  GtkWidget *label32;
  GtkWidget *statisk;
  GtkWidget *enogto;
  GtkWidget *dynamisk;
  GtkWidget *label1;
  GtkWidget *label2;
  GtkWidget *label3;
  GtkWidget *label4;

GtkWidget*
create_uttakssystem ()
{
  uttakssystem = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "uttakssystem", uttakssystem);
  gtk_signal_connect (GTK_OBJECT (uttakssystem), "destroy",
                      GTK_SIGNAL_FUNC (on_uttakssystem_destroy),
                      NULL);
  gtk_window_set_title (GTK_WINDOW (uttakssystem), "uttakssystem");
  gtk_window_set_policy (GTK_WINDOW (uttakssystem), TRUE, TRUE, FALSE);

  notebook1 = gtk_notebook_new ();
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "notebook1", notebook1);
  gtk_widget_show (notebook1);
  gtk_container_add (GTK_CONTAINER (uttakssystem), notebook1);

  vbox1 = gtk_vbox_new (TRUE, 0);
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "vbox1", vbox1);
  gtk_widget_show (vbox1);
  gtk_container_add (GTK_CONTAINER (notebook1), vbox1);

  hbox1 = gtk_hbox_new (FALSE, 0);
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hbox1", hbox1);
  gtk_widget_show (hbox1);
  gtk_box_pack_start (GTK_BOX (vbox1), hbox1, TRUE, TRUE, 0);

  vbox2 = gtk_vbox_new (FALSE, 0);
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "vbox2", vbox2);
  gtk_widget_show (vbox2);
  gtk_box_pack_start (GTK_BOX (hbox1), vbox2, TRUE, TRUE, 0);

  sumpoengsystem = gtk_radio_button_new_with_label (system_group, "Sumpoengsystem");
  system_group = gtk_radio_button_group (GTK_RADIO_BUTTON (sumpoengsystem));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "sumpoengsystem", sumpoengsystem);
  gtk_widget_show (sumpoengsystem);
  gtk_box_pack_start (GTK_BOX (vbox2), sumpoengsystem, TRUE, TRUE, 0);
  GTK_WIDGET_UNSET_FLAGS (sumpoengsystem, GTK_CAN_FOCUS);
  gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (sumpoengsystem), TRUE);

  halver = gtk_check_button_new_with_label ("Halver");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "halver", halver);
  gtk_widget_show (halver);
  gtk_box_pack_start (GTK_BOX (vbox2), halver, TRUE, TRUE, 0);
  gtk_container_border_width (GTK_CONTAINER (halver), 20);

  reduser = gtk_check_button_new_with_label ("Reduser");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "reduser", reduser);
  gtk_widget_show (reduser);
  gtk_box_pack_end (GTK_BOX (vbox2), reduser, TRUE, TRUE, 0);
  gtk_container_border_width (GTK_CONTAINER (reduser), 20);

  table2 = gtk_table_new (2, 10, FALSE);
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "table2", table2);
  gtk_widget_show (table2);
  gtk_box_pack_start (GTK_BOX (hbox1), table2, TRUE, TRUE, 0);

  label33 = gtk_label_new ("Poeng til 1.");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label33", label33);
  gtk_widget_show (label33);
  gtk_table_attach (GTK_TABLE (table2), label33, 0, 1, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label34 = gtk_label_new ("Poeng til 2.");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label34", label34);
  gtk_widget_show (label34);
  gtk_table_attach (GTK_TABLE (table2), label34, 1, 2, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label35 = gtk_label_new ("Poeng til 3.");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label35", label35);
  gtk_widget_show (label35);
  gtk_table_attach (GTK_TABLE (table2), label35, 2, 3, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label36 = gtk_label_new ("Poeng til 4.");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label36", label36);
  gtk_widget_show (label36);
  gtk_table_attach (GTK_TABLE (table2), label36, 3, 4, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label37 = gtk_label_new ("Poeng til 5.");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label37", label37);
  gtk_widget_show (label37);
  gtk_table_attach (GTK_TABLE (table2), label37, 4, 5, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label37a = gtk_label_new ("Poeng til 6.");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label37a", label37a);
  gtk_widget_show (label37a);
  gtk_table_attach (GTK_TABLE (table2), label37a, 5, 6, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label37b = gtk_label_new ("Poeng til 7.");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label37b", label37b);
  gtk_widget_show (label37b);
  gtk_table_attach (GTK_TABLE (table2), label37b, 6, 7, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label37c = gtk_label_new ("Poeng til 8.");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label37c", label37c);
  gtk_widget_show (label37c);
  gtk_table_attach (GTK_TABLE (table2), label37c, 7, 8, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label37d = gtk_label_new ("Poeng til 9.");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label37d", label37d);
  gtk_widget_show (label37d);
  gtk_table_attach (GTK_TABLE (table2), label37d, 8, 9, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label37e = gtk_label_new ("Poeng til 10.");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label37e", label37e);
  gtk_widget_show (label37e);
  gtk_table_attach (GTK_TABLE (table2), label37e, 9, 10, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  poeng1 = gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (3, 0, 20, 0.1, 1, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "poeng1", poeng1);
  gtk_widget_show (poeng1);
  gtk_table_attach (GTK_TABLE (table2), poeng1, 0, 1, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  poeng2 = gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (2, 0, 20, 0.1, 1, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "poeng2", poeng2);
  gtk_widget_show (poeng2);
  gtk_table_attach (GTK_TABLE (table2), poeng2, 1, 2, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  poeng3 = gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1, 0, 20, 0.1, 1, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "poeng3", poeng3);
  gtk_widget_show (poeng3);
  gtk_table_attach (GTK_TABLE (table2), poeng3, 2, 3, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  poeng4 = gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 20, 0.1, 1, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "poeng4", poeng4);
  gtk_widget_show (poeng4);
  gtk_table_attach (GTK_TABLE (table2), poeng4, 3, 4, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  poeng5 = gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 20, 0.1, 1, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "poeng5", poeng5);
  gtk_widget_show (poeng5);
  gtk_table_attach (GTK_TABLE (table2), poeng5, 4, 5, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  poeng6 = gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 20, 0.1, 1, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "poeng6", poeng6);
  gtk_widget_show (poeng6);
  gtk_table_attach (GTK_TABLE (table2), poeng6, 5, 6, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  poeng7 = gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 20, 0.1, 1, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "poeng7", poeng7);
  gtk_widget_show (poeng7);
  gtk_table_attach (GTK_TABLE (table2), poeng7, 6, 7, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  poeng8 = gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 20, 0.1, 1, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "poeng8", poeng8);
  gtk_widget_show (poeng8);
  gtk_table_attach (GTK_TABLE (table2), poeng8, 7, 8, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  poeng9 = gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 20, 0.1, 1, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "poeng9", poeng9);
  gtk_widget_show (poeng9);
  gtk_table_attach (GTK_TABLE (table2), poeng9, 8, 9, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  poeng10 = gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 20, 0.1, 1, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "poeng10", poeng10);
  gtk_widget_show (poeng10);
  gtk_table_attach (GTK_TABLE (table2), poeng10, 9, 10, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  hbox3 = gtk_hbox_new (FALSE, 0);
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hbox3", hbox3);
  gtk_widget_show (hbox3);
  gtk_box_pack_start (GTK_BOX (vbox1), hbox3, FALSE, FALSE, 0);

  poengfratrekssystem = gtk_radio_button_new_with_label (system_group, "Poengfratrekssystem");
  system_group = gtk_radio_button_group (GTK_RADIO_BUTTON (poengfratrekssystem));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "poengfratrekssystem", poengfratrekssystem);
  gtk_widget_show (poengfratrekssystem);
  gtk_box_pack_start (GTK_BOX (hbox3), poengfratrekssystem, FALSE, TRUE, 0);
  GTK_WIDGET_UNSET_FLAGS (poengfratrekssystem, GTK_CAN_FOCUS);

  label25 = gtk_label_new ("Grunntall:");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label25", label25);
  gtk_widget_show (label25);
  gtk_box_pack_start (GTK_BOX (hbox3), label25, TRUE, TRUE, 0);

  grunntall = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (2, 0.1, 20, 0.1, 1, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "grunntall", grunntall);
  gtk_widget_show (grunntall);
  gtk_box_pack_start (GTK_BOX (hbox3), grunntall, TRUE, TRUE, 0);

  label26 = gtk_label_new ("Akkumulering:");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label26", label26);
  gtk_widget_show (label26);
  gtk_box_pack_start (GTK_BOX (hbox3), label26, TRUE, TRUE, 0);

  akkumulering = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1, 1, 20, 1, 1, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "akkumulering", akkumulering);
  gtk_widget_show (akkumulering);
  gtk_box_pack_start (GTK_BOX (hbox3), akkumulering, TRUE, TRUE, 0);
  gtk_scale_set_digits (GTK_SCALE (akkumulering), 0);

  hbox2 = gtk_hbox_new (FALSE, 0);
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hbox2", hbox2);
  gtk_widget_show (hbox2);
  gtk_box_pack_start (GTK_BOX (vbox1), hbox2, TRUE, FALSE, 0);

  deltaksfratrekssystem = gtk_radio_button_new_with_label (system_group, "Deltaksfratrekssystem");
  system_group = gtk_radio_button_group (GTK_RADIO_BUTTON (deltaksfratrekssystem));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "deltaksfratrekssystem", deltaksfratrekssystem);
  gtk_widget_show (deltaksfratrekssystem);
  gtk_box_pack_start (GTK_BOX (hbox2), deltaksfratrekssystem, FALSE, TRUE, 0);
  GTK_WIDGET_UNSET_FLAGS (deltaksfratrekssystem, GTK_CAN_FOCUS);

  regler = gtk_text_new (NULL, NULL);
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "regler", regler);
  gtk_widget_show (regler);
  gtk_container_add (GTK_CONTAINER (notebook1), regler);
  gtk_signal_connect (GTK_OBJECT (regler), "map",
                      GTK_SIGNAL_FUNC (on_regler_map),
                      uttakssystem);

  table1 = gtk_table_new (11, 11, FALSE);
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "table1", table1);
  gtk_widget_show (table1);
  gtk_container_add (GTK_CONTAINER (notebook1), table1);

  label7 = gtk_label_new ("1. deltager");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label7", label7);
  gtk_widget_show (label7);
  gtk_table_attach (GTK_TABLE (table1), label7, 1, 2, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label17 = gtk_label_new ("\305r 2");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label17", label17);
  gtk_widget_show (label17);
  gtk_table_attach (GTK_TABLE (table1), label17, 0, 1, 2, 3,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  hscale0 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale0", hscale0);
  gtk_widget_show (hscale0);
  gtk_table_attach (GTK_TABLE (table1), hscale0, 1, 2, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale0), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale0), GTK_UPDATE_DISCONTINUOUS);

  hscale1 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (2, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale1", hscale1);
  gtk_widget_show (hscale1);
  gtk_table_attach (GTK_TABLE (table1), hscale1, 2, 3, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale1), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale1), GTK_UPDATE_DISCONTINUOUS);

  hscale2 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (3, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale2", hscale2);
  gtk_widget_show (hscale2);
  gtk_table_attach (GTK_TABLE (table1), hscale2, 3, 4, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale2), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale2), GTK_UPDATE_DISCONTINUOUS);

  hscale3 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (4, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale3", hscale3);
  gtk_widget_show (hscale3);
  gtk_table_attach (GTK_TABLE (table1), hscale3, 4, 5, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale3), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale3), GTK_UPDATE_DISCONTINUOUS);

  hscale4 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (5, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale4", hscale4);
  gtk_widget_show (hscale4);
  gtk_table_attach (GTK_TABLE (table1), hscale4, 5, 6, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale4), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale4), GTK_UPDATE_DISCONTINUOUS);

  hscale5 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (6, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale5", hscale5);
  gtk_widget_show (hscale5);
  gtk_table_attach (GTK_TABLE (table1), hscale5, 6, 7, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale5), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale5), GTK_UPDATE_DISCONTINUOUS);

  hscale6 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (7, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale6", hscale6);
  gtk_widget_show (hscale6);
  gtk_table_attach (GTK_TABLE (table1), hscale6, 7, 8, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale6), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale6), GTK_UPDATE_DISCONTINUOUS);

  hscale7 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (8, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale7", hscale7);
  gtk_widget_show (hscale7);
  gtk_table_attach (GTK_TABLE (table1), hscale7, 8, 9, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale7), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale7), GTK_UPDATE_DISCONTINUOUS);

  hscale8 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (9, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale8", hscale8);
  gtk_widget_show (hscale8);
  gtk_table_attach (GTK_TABLE (table1), hscale8, 9, 10, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale8), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale8), GTK_UPDATE_DISCONTINUOUS);

  hscale9 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (10, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale9", hscale9);
  gtk_widget_show (hscale9);
  gtk_table_attach (GTK_TABLE (table1), hscale9, 10, 11, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale9), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale9), GTK_UPDATE_DISCONTINUOUS);

  hscale10 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale10", hscale10);
  gtk_widget_show (hscale10);
  gtk_table_attach (GTK_TABLE (table1), hscale10, 1, 2, 2, 3,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale10), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale10), GTK_UPDATE_DISCONTINUOUS);

  hscale11 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (2, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale11", hscale11);
  gtk_widget_show (hscale11);
  gtk_table_attach (GTK_TABLE (table1), hscale11, 2, 3, 2, 3,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale11), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale11), GTK_UPDATE_DISCONTINUOUS);

  hscale12 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (3, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale12", hscale12);
  gtk_widget_show (hscale12);
  gtk_table_attach (GTK_TABLE (table1), hscale12, 3, 4, 2, 3,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale12), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale12), GTK_UPDATE_DISCONTINUOUS);

  hscale13 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (4, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale13", hscale13);
  gtk_widget_show (hscale13);
  gtk_table_attach (GTK_TABLE (table1), hscale13, 4, 5, 2, 3,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale13), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale13), GTK_UPDATE_DISCONTINUOUS);

  hscale14 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (5, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale14", hscale14);
  gtk_widget_show (hscale14);
  gtk_table_attach (GTK_TABLE (table1), hscale14, 5, 6, 2, 3,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale14), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale14), GTK_UPDATE_DISCONTINUOUS);

  hscale15 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (6, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale15", hscale15);
  gtk_widget_show (hscale15);
  gtk_table_attach (GTK_TABLE (table1), hscale15, 6, 7, 2, 3,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale15), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale15), GTK_UPDATE_DISCONTINUOUS);

  hscale16 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (7, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale16", hscale16);
  gtk_widget_show (hscale16);
  gtk_table_attach (GTK_TABLE (table1), hscale16, 7, 8, 2, 3,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale16), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale16), GTK_UPDATE_DISCONTINUOUS);

  hscale17 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (8, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale17", hscale17);
  gtk_widget_show (hscale17);
  gtk_table_attach (GTK_TABLE (table1), hscale17, 8, 9, 2, 3,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale17), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale17), GTK_UPDATE_DISCONTINUOUS);

  hscale18 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (9, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale18", hscale18);
  gtk_widget_show (hscale18);
  gtk_table_attach (GTK_TABLE (table1), hscale18, 9, 10, 2, 3,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale18), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale18), GTK_UPDATE_DISCONTINUOUS);

  hscale19 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (10, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale19", hscale19);
  gtk_widget_show (hscale19);
  gtk_table_attach (GTK_TABLE (table1), hscale19, 10, 11, 2, 3,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale19), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale19), GTK_UPDATE_DISCONTINUOUS);

  hscale20 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale20", hscale20);
  gtk_widget_show (hscale20);
  gtk_table_attach (GTK_TABLE (table1), hscale20, 1, 2, 3, 4,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale20), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale20), GTK_UPDATE_DISCONTINUOUS);

  hscale21 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (2, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale21", hscale21);
  gtk_widget_show (hscale21);
  gtk_table_attach (GTK_TABLE (table1), hscale21, 2, 3, 3, 4,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale21), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale21), GTK_UPDATE_DISCONTINUOUS);

  hscale22 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (3, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale22", hscale22);
  gtk_widget_show (hscale22);
  gtk_table_attach (GTK_TABLE (table1), hscale22, 3, 4, 3, 4,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale22), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale22), GTK_UPDATE_DISCONTINUOUS);

  hscale23 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (4, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale23", hscale23);
  gtk_widget_show (hscale23);
  gtk_table_attach (GTK_TABLE (table1), hscale23, 4, 5, 3, 4,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale23), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale23), GTK_UPDATE_DISCONTINUOUS);

  hscale24 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (5, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale24", hscale24);
  gtk_widget_show (hscale24);
  gtk_table_attach (GTK_TABLE (table1), hscale24, 5, 6, 3, 4,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale24), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale24), GTK_UPDATE_DISCONTINUOUS);

  hscale25 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (6, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale25", hscale25);
  gtk_widget_show (hscale25);
  gtk_table_attach (GTK_TABLE (table1), hscale25, 6, 7, 3, 4,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale25), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale25), GTK_UPDATE_DISCONTINUOUS);

  hscale26 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (7, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale26", hscale26);
  gtk_widget_show (hscale26);
  gtk_table_attach (GTK_TABLE (table1), hscale26, 7, 8, 3, 4,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale26), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale26), GTK_UPDATE_DISCONTINUOUS);

  hscale27 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (8, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale27", hscale27);
  gtk_widget_show (hscale27);
  gtk_table_attach (GTK_TABLE (table1), hscale27, 8, 9, 3, 4,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale27), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale27), GTK_UPDATE_DISCONTINUOUS);

  hscale28 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (9, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale28", hscale28);
  gtk_widget_show (hscale28);
  gtk_table_attach (GTK_TABLE (table1), hscale28, 9, 10, 3, 4,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale28), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale28), GTK_UPDATE_DISCONTINUOUS);

  hscale29 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (10, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale29", hscale29);
  gtk_widget_show (hscale29);
  gtk_table_attach (GTK_TABLE (table1), hscale29, 10, 11, 3, 4,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale29), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale29), GTK_UPDATE_DISCONTINUOUS);

  hscale30 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale30", hscale30);
  gtk_widget_show (hscale30);
  gtk_table_attach (GTK_TABLE (table1), hscale30, 1, 2, 4, 5,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale30), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale30), GTK_UPDATE_DISCONTINUOUS);

  hscale31 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (2, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale31", hscale31);
  gtk_widget_show (hscale31);
  gtk_table_attach (GTK_TABLE (table1), hscale31, 2, 3, 4, 5,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale31), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale31), GTK_UPDATE_DISCONTINUOUS);

  hscale32 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (3, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale32", hscale32);
  gtk_widget_show (hscale32);
  gtk_table_attach (GTK_TABLE (table1), hscale32, 3, 4, 4, 5,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale32), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale32), GTK_UPDATE_DISCONTINUOUS);

  hscale33 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (4, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale33", hscale33);
  gtk_widget_show (hscale33);
  gtk_table_attach (GTK_TABLE (table1), hscale33, 4, 5, 4, 5,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale33), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale33), GTK_UPDATE_DISCONTINUOUS);

  hscale34 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (5, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale34", hscale34);
  gtk_widget_show (hscale34);
  gtk_table_attach (GTK_TABLE (table1), hscale34, 5, 6, 4, 5,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale34), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale34), GTK_UPDATE_DISCONTINUOUS);

  hscale35 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (6, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale35", hscale35);
  gtk_widget_show (hscale35);
  gtk_table_attach (GTK_TABLE (table1), hscale35, 6, 7, 4, 5,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale35), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale35), GTK_UPDATE_DISCONTINUOUS);

  hscale36 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (7, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale36", hscale36);
  gtk_widget_show (hscale36);
  gtk_table_attach (GTK_TABLE (table1), hscale36, 7, 8, 4, 5,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale36), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale36), GTK_UPDATE_DISCONTINUOUS);

  hscale37 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (8, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale37", hscale37);
  gtk_widget_show (hscale37);
  gtk_table_attach (GTK_TABLE (table1), hscale37, 8, 9, 4, 5,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale37), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale37), GTK_UPDATE_DISCONTINUOUS);

  hscale38 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (9, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale38", hscale38);
  gtk_widget_show (hscale38);
  gtk_table_attach (GTK_TABLE (table1), hscale38, 9, 10, 4, 5,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale38), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale38), GTK_UPDATE_DISCONTINUOUS);

  hscale39 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (10, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale39", hscale39);
  gtk_widget_show (hscale39);
  gtk_table_attach (GTK_TABLE (table1), hscale39, 10, 11, 4, 5,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale39), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale39), GTK_UPDATE_DISCONTINUOUS);

  hscale40 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale40", hscale40);
  gtk_widget_show (hscale40);
  gtk_table_attach (GTK_TABLE (table1), hscale40, 1, 2, 5, 6,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale40), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale40), GTK_UPDATE_DISCONTINUOUS);

  hscale41 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (2, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale41", hscale41);
  gtk_widget_show (hscale41);
  gtk_table_attach (GTK_TABLE (table1), hscale41, 2, 3, 5, 6,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale41), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale41), GTK_UPDATE_DISCONTINUOUS);

  hscale42 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (3, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale42", hscale42);
  gtk_widget_show (hscale42);
  gtk_table_attach (GTK_TABLE (table1), hscale42, 3, 4, 5, 6,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale42), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale42), GTK_UPDATE_DISCONTINUOUS);

  hscale43 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (4, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale43", hscale43);
  gtk_widget_show (hscale43);
  gtk_table_attach (GTK_TABLE (table1), hscale43, 4, 5, 5, 6,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale43), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale43), GTK_UPDATE_DISCONTINUOUS);

  hscale44 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (5, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale44", hscale44);
  gtk_widget_show (hscale44);
  gtk_table_attach (GTK_TABLE (table1), hscale44, 5, 6, 5, 6,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale44), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale44), GTK_UPDATE_DISCONTINUOUS);

  hscale45 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (6, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale45", hscale45);
  gtk_widget_show (hscale45);
  gtk_table_attach (GTK_TABLE (table1), hscale45, 6, 7, 5, 6,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale45), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale45), GTK_UPDATE_DISCONTINUOUS);

  hscale46 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (7, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale46", hscale46);
  gtk_widget_show (hscale46);
  gtk_table_attach (GTK_TABLE (table1), hscale46, 7, 8, 5, 6,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale46), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale46), GTK_UPDATE_DISCONTINUOUS);

  hscale47 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (8, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale47", hscale47);
  gtk_widget_show (hscale47);
  gtk_table_attach (GTK_TABLE (table1), hscale47, 8, 9, 5, 6,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale47), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale47), GTK_UPDATE_DISCONTINUOUS);

  hscale48 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (9, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale48", hscale48);
  gtk_widget_show (hscale48);
  gtk_table_attach (GTK_TABLE (table1), hscale48, 9, 10, 5, 6,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale48), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale48), GTK_UPDATE_DISCONTINUOUS);

  hscale49 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (10, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale49", hscale49);
  gtk_widget_show (hscale49);
  gtk_table_attach (GTK_TABLE (table1), hscale49, 10, 11, 5, 6,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale49), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale49), GTK_UPDATE_DISCONTINUOUS);

  hscale50 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale50", hscale50);
  gtk_widget_show (hscale50);
  gtk_table_attach (GTK_TABLE (table1), hscale50, 1, 2, 6, 7,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale50), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale50), GTK_UPDATE_DISCONTINUOUS);

  hscale51 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (2, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale51", hscale51);
  gtk_widget_show (hscale51);
  gtk_table_attach (GTK_TABLE (table1), hscale51, 2, 3, 6, 7,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale51), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale51), GTK_UPDATE_DISCONTINUOUS);

  hscale52 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (3, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale52", hscale52);
  gtk_widget_show (hscale52);
  gtk_table_attach (GTK_TABLE (table1), hscale52, 3, 4, 6, 7,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale52), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale52), GTK_UPDATE_DISCONTINUOUS);

  hscale53 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (4, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale53", hscale53);
  gtk_widget_show (hscale53);
  gtk_table_attach (GTK_TABLE (table1), hscale53, 4, 5, 6, 7,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale53), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale53), GTK_UPDATE_DISCONTINUOUS);

  hscale54 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (5, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale54", hscale54);
  gtk_widget_show (hscale54);
  gtk_table_attach (GTK_TABLE (table1), hscale54, 5, 6, 6, 7,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale54), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale54), GTK_UPDATE_DISCONTINUOUS);

  hscale55 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (6, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale55", hscale55);
  gtk_widget_show (hscale55);
  gtk_table_attach (GTK_TABLE (table1), hscale55, 6, 7, 6, 7,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale55), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale55), GTK_UPDATE_DISCONTINUOUS);

  hscale56 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (7, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale56", hscale56);
  gtk_widget_show (hscale56);
  gtk_table_attach (GTK_TABLE (table1), hscale56, 7, 8, 6, 7,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale56), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale56), GTK_UPDATE_DISCONTINUOUS);

  hscale57 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (8, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale57", hscale57);
  gtk_widget_show (hscale57);
  gtk_table_attach (GTK_TABLE (table1), hscale57, 8, 9, 6, 7,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale57), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale57), GTK_UPDATE_DISCONTINUOUS);

  hscale58 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (9, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale58", hscale58);
  gtk_widget_show (hscale58);
  gtk_table_attach (GTK_TABLE (table1), hscale58, 9, 10, 6, 7,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale58), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale58), GTK_UPDATE_DISCONTINUOUS);

  hscale59 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (10, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale59", hscale59);
  gtk_widget_show (hscale59);
  gtk_table_attach (GTK_TABLE (table1), hscale59, 10, 11, 6, 7,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale59), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale59), GTK_UPDATE_DISCONTINUOUS);

  hscale60 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale60", hscale60);
  gtk_widget_show (hscale60);
  gtk_table_attach (GTK_TABLE (table1), hscale60, 1, 2, 7, 8,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale60), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale60), GTK_UPDATE_DISCONTINUOUS);

  hscale61 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (2, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale61", hscale61);
  gtk_widget_show (hscale61);
  gtk_table_attach (GTK_TABLE (table1), hscale61, 2, 3, 7, 8,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale61), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale61), GTK_UPDATE_DISCONTINUOUS);

  hscale62 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (3, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale62", hscale62);
  gtk_widget_show (hscale62);
  gtk_table_attach (GTK_TABLE (table1), hscale62, 3, 4, 7, 8,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale62), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale62), GTK_UPDATE_DISCONTINUOUS);

  hscale63 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (4, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale63", hscale63);
  gtk_widget_show (hscale63);
  gtk_table_attach (GTK_TABLE (table1), hscale63, 4, 5, 7, 8,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale63), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale63), GTK_UPDATE_DISCONTINUOUS);

  hscale64 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (5, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale64", hscale64);
  gtk_widget_show (hscale64);
  gtk_table_attach (GTK_TABLE (table1), hscale64, 5, 6, 7, 8,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale64), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale64), GTK_UPDATE_DISCONTINUOUS);

  hscale65 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (6, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale65", hscale65);
  gtk_widget_show (hscale65);
  gtk_table_attach (GTK_TABLE (table1), hscale65, 6, 7, 7, 8,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale65), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale65), GTK_UPDATE_DISCONTINUOUS);

  hscale66 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (7, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale66", hscale66);
  gtk_widget_show (hscale66);
  gtk_table_attach (GTK_TABLE (table1), hscale66, 7, 8, 7, 8,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale66), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale66), GTK_UPDATE_DISCONTINUOUS);

  hscale67 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (8, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale67", hscale67);
  gtk_widget_show (hscale67);
  gtk_table_attach (GTK_TABLE (table1), hscale67, 8, 9, 7, 8,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale67), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale67), GTK_UPDATE_DISCONTINUOUS);

  hscale68 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (9, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale68", hscale68);
  gtk_widget_show (hscale68);
  gtk_table_attach (GTK_TABLE (table1), hscale68, 9, 10, 7, 8,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale68), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale68), GTK_UPDATE_DISCONTINUOUS);

  hscale69 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (10, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale69", hscale69);
  gtk_widget_show (hscale69);
  gtk_table_attach (GTK_TABLE (table1), hscale69, 10, 11, 7, 8,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale69), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale69), GTK_UPDATE_DISCONTINUOUS);

  hscale70 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale70", hscale70);
  gtk_widget_show (hscale70);
  gtk_table_attach (GTK_TABLE (table1), hscale70, 1, 2, 8, 9,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale70), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale70), GTK_UPDATE_DISCONTINUOUS);

  hscale71 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (2, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale71", hscale71);
  gtk_widget_show (hscale71);
  gtk_table_attach (GTK_TABLE (table1), hscale71, 2, 3, 8, 9,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale71), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale71), GTK_UPDATE_DISCONTINUOUS);

  hscale72 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (3, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale72", hscale72);
  gtk_widget_show (hscale72);
  gtk_table_attach (GTK_TABLE (table1), hscale72, 3, 4, 8, 9,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale72), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale72), GTK_UPDATE_DISCONTINUOUS);

  hscale73 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (4, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale73", hscale73);
  gtk_widget_show (hscale73);
  gtk_table_attach (GTK_TABLE (table1), hscale73, 4, 5, 8, 9,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale73), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale73), GTK_UPDATE_DISCONTINUOUS);

  hscale74 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (5, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale74", hscale74);
  gtk_widget_show (hscale74);
  gtk_table_attach (GTK_TABLE (table1), hscale74, 5, 6, 8, 9,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale74), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale74), GTK_UPDATE_DISCONTINUOUS);

  hscale75 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (6, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale75", hscale75);
  gtk_widget_show (hscale75);
  gtk_table_attach (GTK_TABLE (table1), hscale75, 6, 7, 8, 9,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale75), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale75), GTK_UPDATE_DISCONTINUOUS);

  hscale76 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (7, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale76", hscale76);
  gtk_widget_show (hscale76);
  gtk_table_attach (GTK_TABLE (table1), hscale76, 7, 8, 8, 9,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale76), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale76), GTK_UPDATE_DISCONTINUOUS);

  hscale77 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (8, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale77", hscale77);
  gtk_widget_show (hscale77);
  gtk_table_attach (GTK_TABLE (table1), hscale77, 8, 9, 8, 9,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale77), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale77), GTK_UPDATE_DISCONTINUOUS);

  hscale78 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (9, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale78", hscale78);
  gtk_widget_show (hscale78);
  gtk_table_attach (GTK_TABLE (table1), hscale78, 9, 10, 8, 9,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale78), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale78), GTK_UPDATE_DISCONTINUOUS);

  hscale79 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (10, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale79", hscale79);
  gtk_widget_show (hscale79);
  gtk_table_attach (GTK_TABLE (table1), hscale79, 10, 11, 8, 9,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale79), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale79), GTK_UPDATE_DISCONTINUOUS);

  hscale80 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale80", hscale80);
  gtk_widget_show (hscale80);
  gtk_table_attach (GTK_TABLE (table1), hscale80, 1, 2, 9, 10,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale80), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale80), GTK_UPDATE_DISCONTINUOUS);

  hscale81 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (2, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale81", hscale81);
  gtk_widget_show (hscale81);
  gtk_table_attach (GTK_TABLE (table1), hscale81, 2, 3, 9, 10,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale81), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale81), GTK_UPDATE_DISCONTINUOUS);

  hscale82 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (3, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale82", hscale82);
  gtk_widget_show (hscale82);
  gtk_table_attach (GTK_TABLE (table1), hscale82, 3, 4, 9, 10,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale82), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale82), GTK_UPDATE_DISCONTINUOUS);

  hscale83 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (4, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale83", hscale83);
  gtk_widget_show (hscale83);
  gtk_table_attach (GTK_TABLE (table1), hscale83, 4, 5, 9, 10,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale83), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale83), GTK_UPDATE_DISCONTINUOUS);

  hscale84 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (5, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale84", hscale84);
  gtk_widget_show (hscale84);
  gtk_table_attach (GTK_TABLE (table1), hscale84, 5, 6, 9, 10,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale84), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale84), GTK_UPDATE_DISCONTINUOUS);

  hscale85 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (6, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale85", hscale85);
  gtk_widget_show (hscale85);
  gtk_table_attach (GTK_TABLE (table1), hscale85, 6, 7, 9, 10,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale85), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale85), GTK_UPDATE_DISCONTINUOUS);

  hscale86 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (7, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale86", hscale86);
  gtk_widget_show (hscale86);
  gtk_table_attach (GTK_TABLE (table1), hscale86, 7, 8, 9, 10,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale86), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale86), GTK_UPDATE_DISCONTINUOUS);

  hscale87 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (8, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale87", hscale87);
  gtk_widget_show (hscale87);
  gtk_table_attach (GTK_TABLE (table1), hscale87, 8, 9, 9, 10,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale87), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale87), GTK_UPDATE_DISCONTINUOUS);

  hscale88 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (9, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale88", hscale88);
  gtk_widget_show (hscale88);
  gtk_table_attach (GTK_TABLE (table1), hscale88, 9, 10, 9, 10,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale88), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale88), GTK_UPDATE_DISCONTINUOUS);

  hscale89 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (10, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale89", hscale89);
  gtk_widget_show (hscale89);
  gtk_table_attach (GTK_TABLE (table1), hscale89, 10, 11, 9, 10,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale89), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale89), GTK_UPDATE_DISCONTINUOUS);

  hscale90 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale90", hscale90);
  gtk_widget_show (hscale90);
  gtk_table_attach (GTK_TABLE (table1), hscale90, 1, 2, 10, 11,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale90), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale90), GTK_UPDATE_DISCONTINUOUS);

  hscale91 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (2, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale91", hscale91);
  gtk_widget_show (hscale91);
  gtk_table_attach (GTK_TABLE (table1), hscale91, 2, 3, 10, 11,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale91), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale91), GTK_UPDATE_DISCONTINUOUS);

  hscale92 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (3, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale92", hscale92);
  gtk_widget_show (hscale92);
  gtk_table_attach (GTK_TABLE (table1), hscale92, 3, 4, 10, 11,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale92), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale92), GTK_UPDATE_DISCONTINUOUS);

  hscale93 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (4, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale93", hscale93);
  gtk_widget_show (hscale93);
  gtk_table_attach (GTK_TABLE (table1), hscale93, 4, 5, 10, 11,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale93), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale93), GTK_UPDATE_DISCONTINUOUS);

  hscale94 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (5, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale94", hscale94);
  gtk_widget_show (hscale94);
  gtk_table_attach (GTK_TABLE (table1), hscale94, 5, 6, 10, 11,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale94), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale94), GTK_UPDATE_DISCONTINUOUS);

  hscale95 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (6, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale95", hscale95);
  gtk_widget_show (hscale95);
  gtk_table_attach (GTK_TABLE (table1), hscale95, 6, 7, 10, 11,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale95), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale95), GTK_UPDATE_DISCONTINUOUS);

  hscale96 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (7, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale96", hscale96);
  gtk_widget_show (hscale96);
  gtk_table_attach (GTK_TABLE (table1), hscale96, 7, 8, 10, 11,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale96), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale96), GTK_UPDATE_DISCONTINUOUS);

  hscale97 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (8, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale97", hscale97);
  gtk_widget_show (hscale97);
  gtk_table_attach (GTK_TABLE (table1), hscale97, 8, 9, 10, 11,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale97), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale97), GTK_UPDATE_DISCONTINUOUS);

  hscale98 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (9, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale98", hscale98);
  gtk_widget_show (hscale98);
  gtk_table_attach (GTK_TABLE (table1), hscale98, 9, 10, 10, 11,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale98), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale98), GTK_UPDATE_DISCONTINUOUS);

  hscale99 = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (10, 1, 10, 1, 0, 0)));
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "hscale99", hscale99);
  gtk_widget_show (hscale99);
  gtk_table_attach (GTK_TABLE (table1), hscale99, 10, 11, 10, 11,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_scale_set_digits (GTK_SCALE (hscale99), 0);
  gtk_range_set_update_policy (GTK_RANGE (hscale99), GTK_UPDATE_DISCONTINUOUS);

  label38 = gtk_label_new ("2. deltager");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label38", label38);
  gtk_widget_show (label38);
  gtk_table_attach (GTK_TABLE (table1), label38, 2, 3, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label39 = gtk_label_new ("3. deltager");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label39", label39);
  gtk_widget_show (label39);
  gtk_table_attach (GTK_TABLE (table1), label39, 3, 4, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label40 = gtk_label_new ("4. deltager");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label40", label40);
  gtk_widget_show (label40);
  gtk_table_attach (GTK_TABLE (table1), label40, 4, 5, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label41 = gtk_label_new ("5. deltager");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label41", label41);
  gtk_widget_show (label41);
  gtk_table_attach (GTK_TABLE (table1), label41, 5, 6, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label42 = gtk_label_new ("6. deltager");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label42", label42);
  gtk_widget_show (label42);
  gtk_table_attach (GTK_TABLE (table1), label42, 6, 7, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label43 = gtk_label_new ("7. deltager");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label43", label43);
  gtk_widget_show (label43);
  gtk_table_attach (GTK_TABLE (table1), label43, 7, 8, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label44 = gtk_label_new ("8. deltager");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label44", label44);
  gtk_widget_show (label44);
  gtk_table_attach (GTK_TABLE (table1), label44, 8, 9, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label45 = gtk_label_new ("9. deltager");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label45", label45);
  gtk_widget_show (label45);
  gtk_table_attach (GTK_TABLE (table1), label45, 9, 10, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label55 = gtk_label_new ("10. deltager");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label55", label55);
  gtk_widget_show (label55);
  gtk_table_attach (GTK_TABLE (table1), label55, 10, 11, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label46 = gtk_label_new ("\305r 3");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label46", label46);
  gtk_widget_show (label46);
  gtk_table_attach (GTK_TABLE (table1), label46, 0, 1, 3, 4,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label47 = gtk_label_new ("\305r 4");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label47", label47);
  gtk_widget_show (label47);
  gtk_table_attach (GTK_TABLE (table1), label47, 0, 1, 4, 5,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label48 = gtk_label_new ("\305r 5");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label48", label48);
  gtk_widget_show (label48);
  gtk_table_attach (GTK_TABLE (table1), label48, 0, 1, 5, 6,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label49 = gtk_label_new ("\305r 6");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label49", label49);
  gtk_widget_show (label49);
  gtk_table_attach (GTK_TABLE (table1), label49, 0, 1, 6, 7,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label50 = gtk_label_new ("\305r 7");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label50", label50);
  gtk_widget_show (label50);
  gtk_table_attach (GTK_TABLE (table1), label50, 0, 1, 7, 8,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label51 = gtk_label_new ("\305r 8");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label51", label51);
  gtk_widget_show (label51);
  gtk_table_attach (GTK_TABLE (table1), label51, 0, 1, 8, 9,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label52 = gtk_label_new ("\305r 9");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label52", label52);
  gtk_widget_show (label52);
  gtk_table_attach (GTK_TABLE (table1), label52, 0, 1, 9, 10,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label53 = gtk_label_new ("\305r 1");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label53", label53);
  gtk_widget_show (label53);
  gtk_table_attach (GTK_TABLE (table1), label53, 0, 1, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label54 = gtk_label_new ("\305r 10");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label54", label54);
  gtk_widget_show (label54);
  gtk_table_attach (GTK_TABLE (table1), label54, 0, 1, 10, 11,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  resultat = gtk_table_new (3, 2, FALSE);
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "resultat", resultat);
  gtk_widget_show (resultat);
  gtk_container_add (GTK_CONTAINER (notebook1), resultat);
  gtk_signal_connect (GTK_OBJECT (resultat), "map",
                      GTK_SIGNAL_FUNC (on_resultat_map),
                      uttakssystem);

  label30 = gtk_label_new ("Statisk:");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label30", label30);
  gtk_widget_show (label30);
  gtk_table_attach (GTK_TABLE (resultat), label30, 0, 1, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label31 = gtk_label_new ("1. og 2.:");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label31", label31);
  gtk_widget_show (label31);
  gtk_table_attach (GTK_TABLE (resultat), label31, 0, 1, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label32 = gtk_label_new ("Dynamisk:");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label32", label32);
  gtk_widget_show (label32);
  gtk_table_attach (GTK_TABLE (resultat), label32, 0, 1, 2, 3,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  statisk = gtk_text_new (NULL, NULL);
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "statisk", statisk);
  gtk_widget_show (statisk);
  gtk_table_attach (GTK_TABLE (resultat), statisk, 1, 2, 0, 1,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_widget_set_usize (statisk, 454, -2);

  enogto = gtk_text_new (NULL, NULL);
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "enogto", enogto);
  gtk_widget_show (enogto);
  gtk_table_attach (GTK_TABLE (resultat), enogto, 1, 2, 1, 2,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  dynamisk = gtk_text_new (NULL, NULL);
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "dynamisk", dynamisk);
  gtk_widget_show (dynamisk);
  gtk_table_attach (GTK_TABLE (resultat), dynamisk, 1, 2, 2, 3,
                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);

  label1 = gtk_label_new ("Uttakssystem");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label1", label1);
  gtk_widget_show (label1);
  set_notebook_tab (notebook1, 0, label1);

  label2 = gtk_label_new ("Regler");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label2", label2);
  gtk_widget_show (label2);
  set_notebook_tab (notebook1, 1, label2);

  label3 = gtk_label_new ("Plassering");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label3", label3);
  gtk_widget_show (label3);
  set_notebook_tab (notebook1, 2, label3);

  label4 = gtk_label_new ("Resultat");
  gtk_object_set_data (GTK_OBJECT (uttakssystem), "label4", label4);
  gtk_widget_show (label4);
  set_notebook_tab (notebook1, 3, label4);

  return uttakssystem;
}

